summaryrefslogtreecommitdiffstats
path: root/templates/annotated/basicapp.py
diff options
context:
space:
mode:
Diffstat (limited to 'templates/annotated/basicapp.py')
-rw-r--r--templates/annotated/basicapp.py14
1 files changed, 7 insertions, 7 deletions
diff --git a/templates/annotated/basicapp.py b/templates/annotated/basicapp.py
index 0a44593..44b6681 100644
--- a/templates/annotated/basicapp.py
+++ b/templates/annotated/basicapp.py
@@ -35,7 +35,7 @@ copyright holder.
import sys
-from tdecore import KApplication, KCmdLineArgs, KAboutData
+from tdecore import TDEApplication, KCmdLineArgs, KAboutData
from tdeui import KMainWindow
"""
@@ -76,9 +76,9 @@ aboutData.addAuthor ("author2", "they did something else", "[email protected]
# Pass the command line arguments and aboutData to
# KCmdLineArgs - this is where KDE will look for
# this information. The KApplication constructor
# used below *requires* the args are processed
# *before* KApplication is instantiated. There
# is an alternate constructor that takes sys.argv
# as an argument (see minimal.py)
@@ -96,10 +96,10 @@ KCmdLineArgs.init (sys.argv, aboutData)
# of tuples
KCmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
# instantiate KApplication - no other TQObject
# or TQWidget based classes can be instantiated
-# until there is a KApplication instance
-app = KApplication ()
+# until there is a TDEApplication instance
+app = TDEApplication ()
# instantiate the subclass of KMainWindow
mainWindow = MainWin (None, "main window")
@@ -107,7 +107,7 @@ mainWindow = MainWin (None, "main window")
# create the display
mainWindow.show()
# run KApplication's event loop until the
# program exits
app.exec_loop()
@@ -76,9 +76,9 @@ aboutData.addAuthor ("author2", "they did something else", "[email protected]
# Pass the command line arguments and aboutData to
# KCmdLineArgs - this is where KDE will look for
-# this information. The KApplication constructor
+# this information. The TDEApplication constructor
# used below *requires* the args are processed
@@ -76,9 +76,9 @@ aboutData.addAuthor ("author2", "they did something else", "[email protected]
# used below *requires* the args are processed
-# *before* KApplication is instantiated. There
+# *before* TDEApplication is instantiated. There
# is an alternate constructor that takes sys.argv
# as an argument (see minimal.py)
@@ -96,10 +96,10 @@ KCmdLineArgs.init (sys.argv, aboutData)
# of tuples
KCmdLineArgs.addCmdLineOptions ([("+files", "File to open")])
-# instantiate KApplication - no other TQObject
+# instantiate TDEApplication - no other TQObject
# or TQWidget based classes can be instantiated
@@ -107,7 +107,7 @@ mainWindow = MainWin (None, "main window")
# create the display
mainWindow.show()
-# run KApplication's event loop until the
+# run TDEApplication's event loop until the
# program exits
app.exec_loop()